import { Injectable } from "@angular/core";
import { Observable } from "rxjs/Observable";
import PouchDB from "pouchdb";

import * as PouchFind from "pouchdb-find";

import "rxjs/add/observable/throw";
import "rxjs/add/observable/fromPromise";
import "rxjs/add/observable/from";
import "rxjs/add/operator/concatMap";

PouchDB.plugin(PouchFind);

@Injectable()
export class PouchService {

    pouchDB: any;

    constructor() {
        this.initialize();
    }

    /**
     *
     */
    private initialize(destroy?: boolean): Observable<any> {
        this.pouchDB = new PouchDB("odoo", {
            auto_compaction: true
        });

        return Observable.fromPromise(this.pouchDB.createIndex({
            index: {
                fields: ['odoo_model']
            }
        }));
    }

    /**
     *
     */
    save(data: any): Observable<any> {
        if (!data.odoo_model) {
            return Observable.throw("Error: Cannot save data without model name");
        }

        return Observable.fromPromise(this.pouchDB.post(data));
    }

    /**
     *
     */
    remove(data: any): Observable<any> {
        if (!data._id || !data._rev) {
            return Observable.throw("Error: Cannot remove data without id or rev");
        }

        return Observable.fromPromise(this.pouchDB.remove(data));
    }

    /**
     *
     */
    removeAll(type: string): Observable<any> {
        return this.getAll(type).concatMap(result => Observable.from(result.docs)).concatMap(doc => this.remove(Object.assign(doc, { _deleted: true })));
    }

    /**
     *
     */
    get(data: any): Observable<any> {
        if (!data._id) {
            return Observable.throw("Error: Cannot get data without id");
        }

        return Observable.fromPromise(this.pouchDB.get(data._id));
    }

    /**
     *
     */
    getAll(odoo_model: string): Observable<any> {
        return Observable.fromPromise(this.pouchDB.find({
            selector: {
                odoo_model: {
                    $eq: odoo_model
                }
            }
        }));
    }

    /**
     *
     */
    destroy(): Observable<any> {
        return Observable.fromPromise(this.pouchDB.destroy());
    }

    /**
     *
     */
    destroyAndInitialize() {
        return this.destroy().concatMap(response => this.initialize(response.ok));
    }
}
